#!/bin/ksh
#

########################################################
# set paths and files

MODULE="NokGSM"
RELEASE="14.1.11.0.20"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarDir=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### stamping ts
s_yyyymmdd=`(date "+%Y%m%d")`
s_hhmmss=`(date "+%H%M%S")`
mkdir -p $SourceDir/Backup
echo "$s_yyyymmdd.$s_hhmmss" > $SourceDir/Backup/.ts.txt

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${FLEXPM_BASE} ]]; then
     echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${NokGSM_HOME} ]]; then
     echo "Env variable NokGSM_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $FLEXPM_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarDir $FLEXPM_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      exit 2
    fi


    ###### module installation customerize here...

    cd $PM_HOME/peik/xml
    touch parser.err
    chmod 777 parser.err

    echo "### running dict_update ###" 
    cd $NokGSM_HOME/peik
    make dict_update
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in make dict_update"
      exit 2
    fi

       echo "### completed dict_update ###"

       ### SEAde64824 : regen scenario query to cater active/complete scenario with new entities
       echo "+ running regen_sce_query.sql..."
       echo "@${WorkDir}/regen_sce_query.sql" | sqlplus -s ${DB_CONNECT}
       echo " regen_sce_query.sql done."

       #recompile all invalid objects (except for views...):
       echo "+ recompiling invalid object(s)..."
       chmod u+x ${WorkDir}/recompile_schema.sh
       ${WorkDir}/recompile_schema.sh

       #and we recompile for invalid views here...
       echo "+ recompiling invalid view(s)..."
       chmod u+x ${WorkDir}/recompile_view.sh
       ${WorkDir}/recompile_view.sh
       echo " recompiled done."

       ### remake for MSCpm/M12 loader ###
       if ! [ -d ${NokGSM_HOME}/vendor/Nokia/GSM/1.3/NokiaGSM_loader/MSCpm/M12/config ] ; then
          echo "Cant locate ${NokGSM_HOME}/vendor/Nokia/GSM/1.3/NokiaGSM_loader/MSCpm/M12/config for remake"
          exit 1
       fi

       cd ${NokGSM_HOME}/vendor/Nokia/GSM/1.3/NokiaGSM_loader/MSCpm/M12/config
       make def_update 

       ### remake for BSSpm loader ###
       if ! [ -d ${NokGSM_HOME}/vendor/Nokia/GSM/1.3/NokiaGSM_loader/BSSpm/config ] ; then
          echo "Cant locate ${NokGSM_HOME}/vendor/Nokia/GSM/1.3/NokiaGSM_loader/BSSpm/config for remake"
          exit 1
       fi

       cd ${NokGSM_HOME}/vendor/Nokia/GSM/1.3/NokiaGSM_loader/BSSpm/config
       make def_update

       ### recompile this...

       if ! [ -d ${NokGSM_HOME}/vendor/Nokia/GSM/Network ] ; then
          echo "Cant locate ${NokGSM_HOME}/vendor/Nokia/GSM/Network for recompile"
          exit 1
       fi 

       echo "@${NokGSM_HOME}/vendor/Nokia/GSM/Network/validate_fullkey.sql" | sqlplus -s ${DB_CONNECT}
       echo "@${NokGSM_HOME}/vendor/Nokia/GSM/Network/wm_activate_parent_list.sql" | sqlplus -s ${DB_CONNECT}

       date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
       echo ""

